# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SUMA_METADATA = Metadata(
    id="ab82cac109ef47be190dcdcd83a806490c935c41.boutiques",
    name="suma",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SumaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `suma(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def suma(
    runner: Runner | None = None,
) -> SumaOutputs:
    """
    SUMA: Surface Mapper for visualization and analysis of brain data.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/suma.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SumaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SUMA_METADATA)
    cargs = []
    cargs.append("suma")
    cargs.append("[MODE]")
    cargs.append("[OPTIONS]")
    ret = SumaOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SUMA_METADATA",
    "SumaOutputs",
    "suma",
]
