# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMG2STDCOORD_METADATA = Metadata(
    id="ebbbc78d99eb06d9c9f6e6f5f7ea7f7feab66bdd.boutiques",
    name="img2stdcoord",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Img2stdcoordOutputs(typing.NamedTuple):
    """
    Output object returned when calling `img2stdcoord(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def img2stdcoord(
    coordinate_file: str,
    runner: Runner | None = None,
) -> Img2stdcoordOutputs:
    """
    Transforms image coordinates using standard space transformations.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    Args:
        coordinate_file: Filename containing coordinates. If '-' is used,\
            coordinates are read from standard input.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Img2stdcoordOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMG2STDCOORD_METADATA)
    cargs = []
    cargs.append("img2stdcoord")
    cargs.append("[OPTIONS]")
    cargs.append(coordinate_file)
    ret = Img2stdcoordOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMG2STDCOORD_METADATA",
    "Img2stdcoordOutputs",
    "img2stdcoord",
]
