# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MCCUTUP_METADATA = Metadata(
    id="38f27698b0fd81106186cbbb3524e89f2b2da116.boutiques",
    name="mccutup",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class MccutupOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mccutup(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """Output file"""


def mccutup(
    input_: InputPathType,
    runner: Runner | None = None,
) -> MccutupOutputs:
    """
    FSL mccutup tool.
    
    Author: FSL
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/
    
    Args:
        input_: Input file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MccutupOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MCCUTUP_METADATA)
    cargs = []
    cargs.append("/usr/local/fsl/bin/mccutup")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_))
    ret = MccutupOutputs(
        root=execution.output_file("."),
        output=execution.output_file("[OUTPUT_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MCCUTUP_METADATA",
    "MccutupOutputs",
    "mccutup",
]
