# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DRIVE_AFNI_METADATA = Metadata(
    id="189b3cf933c3ef7aadb2f61deba82c51cdb891cb.boutiques",
    name="@DriveAfni",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDriveAfniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__drive_afni(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_jpg: OutputPathType
    """Output file created by the DriveAfni script"""


def v__drive_afni(
    runner: Runner | None = None,
) -> VDriveAfniOutputs:
    """
    A demo program for driving 'afni' from a script.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@DriveAfni.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDriveAfniOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DRIVE_AFNI_METADATA)
    cargs = []
    cargs.append("DriveAfni")
    ret = VDriveAfniOutputs(
        root=execution.output_file("."),
        output_jpg=execution.output_file("./SavedAxiale.jpg"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDriveAfniOutputs",
    "V__DRIVE_AFNI_METADATA",
    "v__drive_afni",
]
