# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_4SWAP_METADATA = Metadata(
    id="e5570d9e2ac4432fc7c28c15ab79f0523c5a5345.boutiques",
    name="4swap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V4swapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_4swap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_4swap(
    runner: Runner | None = None,
) -> V4swapOutputs:
    """
    Swaps byte quadruples on the listed files.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/4swap.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V4swapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_4SWAP_METADATA)
    cargs = []
    cargs.append("4swap")
    cargs.append("[-q]")
    cargs.append("[FILES...]")
    ret = V4swapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V4swapOutputs",
    "V_4SWAP_METADATA",
    "v_4swap",
]
