# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TBSS_4_PRESTATS_METADATA = Metadata(
    id="6d72a9e868ac4e6fa0f862c6199672dd62007438.boutiques",
    name="tbss_4_prestats",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Tbss4PrestatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tbss_4_prestats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def tbss_4_prestats(
    threshold: float = 0.2,
    runner: Runner | None = None,
) -> Tbss4PrestatsOutputs:
    """
    A tool for thresholding the Mean FA Skeleton in TBSS analysis.
    
    Author: FMRIB Software Library
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/TBSS/UserGuide
    
    Args:
        threshold: Thresholding value for the Mean FA Skeleton; recommended\
            value is 0.2.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Tbss4PrestatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TBSS_4_PRESTATS_METADATA)
    cargs = []
    cargs.append("tbss_4_prestats")
    cargs.append(str(threshold))
    ret = Tbss4PrestatsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TBSS_4_PRESTATS_METADATA",
    "Tbss4PrestatsOutputs",
    "tbss_4_prestats",
]
