# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MIST_DISPLAY_METADATA = Metadata(
    id="a3dfab2cb8ff840618615f7b6468256b6544fad3.boutiques",
    name="mist_display",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class MistDisplayOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mist_display(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mist_display(
    mode: typing.Literal["simple", "pvals", "noscalars"],
    help_: bool = False,
    runner: Runner | None = None,
) -> MistDisplayOutputs:
    """
    Tool to show scalars on mesh.
    
    Author: Unknown
    
    Args:
        mode: Mode for displaying scalars on mesh.
        help_: Show help message and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MistDisplayOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MIST_DISPLAY_METADATA)
    cargs = []
    cargs.append("mist_display")
    cargs.append(mode)
    if help_:
        cargs.append("--help")
    ret = MistDisplayOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MIST_DISPLAY_METADATA",
    "MistDisplayOutputs",
    "mist_display",
]
