# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

POSSUM_METADATA = Metadata(
    id="833115a38119437ac7f8970c044577f2cf37bc68.boutiques",
    name="possum",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PossumOutputs(typing.NamedTuple):
    """
    Output object returned when calling `possum(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_matrix: OutputPathType
    """Output matrix file generated by possum"""


def possum(
    runner: Runner | None = None,
) -> PossumOutputs:
    """
    Positron emission tomography (PET) simulation tool as part of FSL suite.
    
    Author: University of Oxford (Ivana Drobnjak)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/POSSUM
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PossumOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(POSSUM_METADATA)
    cargs = []
    cargs.append("possum")
    cargs.append("-i")
    cargs.append("<input")
    cargs.append("phantom")
    cargs.append("volume>")
    cargs.append("-x")
    cargs.append("<MR")
    cargs.append("parameters")
    cargs.append("matrix>")
    cargs.append("-p")
    cargs.append("<pulse>")
    cargs.append("-f")
    cargs.append("<RF")
    cargs.append("slice")
    cargs.append("profile>")
    cargs.append("-m")
    cargs.append("<motion")
    cargs.append("file>")
    cargs.append("-o")
    cargs.append("<output")
    cargs.append("signal")
    cargs.append("matrix>")
    cargs.append("[additional")
    cargs.append("options]")
    ret = PossumOutputs(
        root=execution.output_file("."),
        output_matrix=execution.output_file("[OUTPUT_MATRIX].mat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "POSSUM_METADATA",
    "PossumOutputs",
    "possum",
]
