# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DGRAYPLOT_METADATA = Metadata(
    id="89e4649907a2a1854a7fce55508f9096cc0c7563.boutiques",
    name="1dgrayplot",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dgrayplotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dgrayplot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_1dgrayplot(
    tsfile: InputPathType,
    runner: Runner | None = None,
) -> V1dgrayplotOutputs:
    """
    Graphs the columns of a *.1D type time series file to the screen in grayscale.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dgrayplot.html
    
    Args:
        tsfile: Input time series file (*.1D format).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dgrayplotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DGRAYPLOT_METADATA)
    cargs = []
    cargs.append("1dgrayplot")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(tsfile))
    ret = V1dgrayplotOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dgrayplotOutputs",
    "V_1DGRAYPLOT_METADATA",
    "v_1dgrayplot",
]
