# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NICCC_METADATA = Metadata(
    id="d138035fa76e2880239e1ebb0517f36ddc0b13fa.boutiques",
    name="niccc",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class NicccOutputs(typing.NamedTuple):
    """
    Output object returned when calling `niccc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stderr_output: OutputPathType
    """Results output to stderr"""


def niccc(
    streamspec: str,
    runner: Runner | None = None,
) -> NicccOutputs:
    """
    A program for conducting certain NIML tests on input from streamspec and write
    the results to stderr.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/niccc.html
    
    Args:
        streamspec: A string defining a NIML stream.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NicccOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NICCC_METADATA)
    cargs = []
    cargs.append("niccc")
    cargs.append("[OPTIONS]")
    cargs.append(streamspec)
    ret = NicccOutputs(
        root=execution.output_file("."),
        stderr_output=execution.output_file("stderr"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NICCC_METADATA",
    "NicccOutputs",
    "niccc",
]
