# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UBER_PROC_PY_METADATA = Metadata(
    id="36e6d5db2ea98de96052bdf63be621bc71fbff06.boutiques",
    name="uber_proc.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class UberProcPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `uber_proc_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def uber_proc_py(
    results_dir: str | None = None,
    runner: Runner | None = None,
) -> UberProcPyOutputs:
    """
    Uber processing tool - work in progress.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/uber_proc.py.html
    
    Args:
        results_dir: Directory where results will be placed. Default is a new\
            'uber_results' directory in the current working directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `UberProcPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UBER_PROC_PY_METADATA)
    cargs = []
    cargs.append("uber_proc.py")
    if results_dir is not None:
        cargs.append(results_dir)
    ret = UberProcPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UBER_PROC_PY_METADATA",
    "UberProcPyOutputs",
    "uber_proc_py",
]
