# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__NO_POUND_METADATA = Metadata(
    id="e8966af56389c1235a2a32ff16269adde3aec8d4.boutiques",
    name="@NoPound",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VNoPoundOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__no_pound(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__no_pound(
    afni_files: list[str],
    runner: Runner | None = None,
) -> VNoPoundOutputs:
    """
    Replaces all # characters in AFNI filenames with a -.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@NoPound.html
    
    Args:
        afni_files: List of AFNI files where # characters should be replaced\
            with -.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VNoPoundOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__NO_POUND_METADATA)
    cargs = []
    cargs.append("@NoPound")
    cargs.extend(afni_files)
    ret = VNoPoundOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VNoPoundOutputs",
    "V__NO_POUND_METADATA",
    "v__no_pound",
]
