# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UBER_SKEL_PY_METADATA = Metadata(
    id="072808117e1f9ebcb9f514ee1fafce9b67b7215b.boutiques",
    name="uber_skel.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class UberSkelPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `uber_skel_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def uber_skel_py(
    runner: Runner | None = None,
) -> UberSkelPyOutputs:
    """
    Sample uber processing program for initializing user and control variables, with
    options for both GUI and non-GUI modes.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/uber_skel.py.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `UberSkelPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UBER_SKEL_PY_METADATA)
    cargs = []
    cargs.append("uber_skel.py")
    cargs.append("[OPTIONS]")
    ret = UberSkelPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UBER_SKEL_PY_METADATA",
    "UberSkelPyOutputs",
    "uber_skel_py",
]
