# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

QDELAUNAY_METADATA = Metadata(
    id="230edbfb789d820a73d4a6e8222bf0d4bc599486.boutiques",
    name="qdelaunay",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class QdelaunayOutputs(typing.NamedTuple):
    """
    Output object returned when calling `qdelaunay(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def qdelaunay(
    input_file: InputPathType,
    runner: Runner | None = None,
) -> QdelaunayOutputs:
    """
    Compute the Delaunay triangulation using Qhull.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/qdelaunay.html
    
    Args:
        input_file: Input file containing point coordinates.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `QdelaunayOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(QDELAUNAY_METADATA)
    cargs = []
    cargs.append("qdelaunay")
    cargs.append("[OPTION_FLAGS]")
    cargs.append("<")
    cargs.append(execution.input_file(input_file))
    ret = QdelaunayOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "QDELAUNAY_METADATA",
    "QdelaunayOutputs",
    "qdelaunay",
]
