# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_RSFMRI_MOTION_GROUP_DEMO_METADATA = Metadata(
    id="2bc3003582dfbea0e9f77aa8215552906ad0cb34.boutiques",
    name="@Install_RSFMRI_Motion_Group_Demo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallRsfmriMotionGroupDemoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_rsfmri_motion_group_demo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    afni_demo_dir: OutputPathType
    """Directory where the demo data and scripts are set up."""


def v__install_rsfmri_motion_group_demo(
    output_dir: str,
    runner: Runner | None = None,
) -> VInstallRsfmriMotionGroupDemoOutputs:
    """
    Installs and sets up an AFNI InstaCorr demo archive, based on 190 Cambridge
    subjects from FCON_1000.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_RSFMRI_Motion_Group_Demo.html
    
    Args:
        output_dir: Directory where the AFNI_Demo_Motion_Groups will be set up.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallRsfmriMotionGroupDemoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_RSFMRI_MOTION_GROUP_DEMO_METADATA)
    cargs = []
    cargs.append("@Install_RSFMRI_Motion_Group_Demo")
    cargs.append(output_dir)
    ret = VInstallRsfmriMotionGroupDemoOutputs(
        root=execution.output_file("."),
        afni_demo_dir=execution.output_file(output_dir + "/AFNI_Demo_Motion_Groups"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallRsfmriMotionGroupDemoOutputs",
    "V__INSTALL_RSFMRI_MOTION_GROUP_DEMO_METADATA",
    "v__install_rsfmri_motion_group_demo",
]
