# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_AFNI_RETINO_DEMO_METADATA = Metadata(
    id="1899f0af35d9fd5f3da22643ad090264cbb802f7.boutiques",
    name="@Install_AfniRetinoDemo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallAfniRetinoDemoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_afni_retino_demo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    retino_demo_dir: OutputPathType
    """Output directory where the demo files are installed"""


def v__install_afni_retino_demo(
    output_dir: str,
    runner: Runner | None = None,
) -> VInstallAfniRetinoDemoOutputs:
    """
    Installs and runs demo script for the retinotopy pipeline demo.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_AfniRetinoDemo.html
    
    Args:
        output_dir: Output directory where the demo will be installed and run.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallAfniRetinoDemoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_AFNI_RETINO_DEMO_METADATA)
    cargs = []
    cargs.append("@Install_AfniRetinoDemo")
    cargs.append(output_dir)
    ret = VInstallAfniRetinoDemoOutputs(
        root=execution.output_file("."),
        retino_demo_dir=execution.output_file(output_dir + "/AfniRetinoDemo"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallAfniRetinoDemoOutputs",
    "V__INSTALL_AFNI_RETINO_DEMO_METADATA",
    "v__install_afni_retino_demo",
]
