# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONCAT_BVARS_METADATA = Metadata(
    id="6a9bf9f25c132f92894f26ddadc2707ebb8f44eb.boutiques",
    name="concat_bvars",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ConcatBvarsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `concat_bvars(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Concatenated output .bvars file"""


def concat_bvars(
    output_bvars: InputPathType,
    runner: Runner | None = None,
) -> ConcatBvarsOutputs:
    """
    Concatenate multiple .bvars files into a single .bvars file.
    
    Author: Unknown
    
    Args:
        output_bvars: Output .bvars file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConcatBvarsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONCAT_BVARS_METADATA)
    cargs = []
    cargs.append("concat_bvars")
    cargs.append(execution.input_file(output_bvars))
    cargs.append("[INPUT_BVARS...]")
    ret = ConcatBvarsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(output_bvars).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONCAT_BVARS_METADATA",
    "ConcatBvarsOutputs",
    "concat_bvars",
]
