# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DSVM_METADATA = Metadata(
    id="0f6c752a6ae915fa2d5ee354357ef3df203df0d6.boutiques",
    name="3dsvm",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dsvmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dsvm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_model: OutputPathType
    """Output model file in .1D format."""
    out_alpha: OutputPathType
    """Output alphas file in .1D format."""
    out_bucket: OutputPathType
    """Output bucket file in .1D format."""
    out_predictions: OutputPathType
    """Output predictions file in .1D format."""


def v_3dsvm(
    runner: Runner | None = None,
) -> V3dsvmOutputs:
    """
    Support vector machine analysis of brain data using the SVM-light package.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dsvm.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dsvmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DSVM_METADATA)
    cargs = []
    cargs.append("3dsvm")
    cargs.append("[OPTIONS]")
    ret = V3dsvmOutputs(
        root=execution.output_file("."),
        out_model=execution.output_file("model_{output}.1D"),
        out_alpha=execution.output_file("alpha_{output}.1D"),
        out_bucket=execution.output_file("bucket_{output}.1D"),
        out_predictions=execution.output_file("predictions_{output}.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dsvmOutputs",
    "V_3DSVM_METADATA",
    "v_3dsvm",
]
