# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMGLOB_METADATA = Metadata(
    id="04388dd1ed84da67a1aac9da7d9b7d85a0f8a49c.boutiques",
    name="imglob",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ImglobOutputs(typing.NamedTuple):
    """
    Output object returned when calling `imglob(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def imglob(
    input_list: list[str],
    multiple_extensions: bool = False,
    runner: Runner | None = None,
) -> ImglobOutputs:
    """
    Tool for generating image lists with specific extensions.
    
    Author: Software Author
    
    Args:
        input_list: List of image names or file paths.
        multiple_extensions: Output list of images with full extensions.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImglobOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMGLOB_METADATA)
    cargs = []
    cargs.append("imglob")
    if multiple_extensions:
        cargs.append("-extensions")
    cargs.extend(input_list)
    ret = ImglobOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMGLOB_METADATA",
    "ImglobOutputs",
    "imglob",
]
