# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DRIVE_SUMA_METADATA = Metadata(
    id="f0a765d1c6ee3fa4cf10d62c557d251571658b10.boutiques",
    name="@DriveSuma",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDriveSumaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__drive_suma(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__drive_suma(
    h_aspx: bool = False,
    runner: Runner | None = None,
) -> VDriveSumaOutputs:
    """
    A script to demonstrate how to drive suma from the command line.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@DriveSuma.html
    
    Args:
        h_aspx: Sphinx formatted help string with auto tagging of options.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDriveSumaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DRIVE_SUMA_METADATA)
    cargs = []
    cargs.append("@DriveSuma")
    if h_aspx:
        cargs.append("-h_aspx")
    ret = VDriveSumaOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDriveSumaOutputs",
    "V__DRIVE_SUMA_METADATA",
    "v__drive_suma",
]
