# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__RETINO_PROC_METADATA = Metadata(
    id="68decbff812b0a172bd91c6f856d4c4c196ae1d0.boutiques",
    name="@RetinoProc",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VRetinoProcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__retino_proc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__retino_proc(
    runner: Runner | None = None,
) -> VRetinoProcOutputs:
    """
    A script to process retinotopic FMRI data, using AFNI's 3dRetinoPhase and
    SurfRetinMap.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@RetinoProc.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VRetinoProcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__RETINO_PROC_METADATA)
    cargs = []
    cargs.append("@RetinoProc")
    cargs.append("[INPUT_FILES]")
    cargs.append("[OPTIONS]")
    ret = VRetinoProcOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VRetinoProcOutputs",
    "V__RETINO_PROC_METADATA",
    "v__retino_proc",
]
