# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_MEICA_DEMO_METADATA = Metadata(
    id="097156093c1a5e931817d9a774ed678044201473.boutiques",
    name="@Install_MEICA_Demo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallMeicaDemoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_meica_demo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    readme_file: OutputPathType
    """Details of the demo archive"""


def v__install_meica_demo(
    demo_archive: InputPathType,
    runner: Runner | None = None,
) -> VInstallMeicaDemoOutputs:
    """
    Installs the demo archive for Prantik Kundu MEICA denoising tools. After the
    archive is downloaded and unpacked, see its README.txt for details.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_MEICA_Demo.html
    
    Args:
        demo_archive: Demo archive to install (e.g. meica_demo.zip).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallMeicaDemoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_MEICA_DEMO_METADATA)
    cargs = []
    cargs.append("Install_MEICA_Demo")
    cargs.append(execution.input_file(demo_archive))
    ret = VInstallMeicaDemoOutputs(
        root=execution.output_file("."),
        readme_file=execution.output_file("README.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallMeicaDemoOutputs",
    "V__INSTALL_MEICA_DEMO_METADATA",
    "v__install_meica_demo",
]
