# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_FATCAT_DEMO2_METADATA = Metadata(
    id="30d3dec7d043fb270647b12bcab46b5a0618ac86.boutiques",
    name="@Install_FATCAT_DEMO2",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallFatcatDemo2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_fatcat_demo2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__install_fatcat_demo2(
    use_curl: bool = False,
    runner: Runner | None = None,
) -> VInstallFatcatDemo2Outputs:
    """
    Installs the demo archive for Paul Taylor's tractography tools.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_FATCAT_DEMO2.html
    
    Args:
        use_curl: Use curl to download archive.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallFatcatDemo2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_FATCAT_DEMO2_METADATA)
    cargs = []
    cargs.append("@Install_FATCAT_DEMO2")
    if use_curl:
        cargs.append("-curl")
    ret = VInstallFatcatDemo2Outputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallFatcatDemo2Outputs",
    "V__INSTALL_FATCAT_DEMO2_METADATA",
    "v__install_fatcat_demo2",
]
