# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_DSET_INFO_METADATA = Metadata(
    id="ff980f3e3e262bfc83a21f1bbaca617d1e5c8d48.boutiques",
    name="SurfDsetInfo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfDsetInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_dset_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surf_dset_info(
    runner: Runner | None = None,
) -> SurfDsetInfoOutputs:
    """
    Provides information about surface datasets (DSET).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfDsetInfo.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfDsetInfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_DSET_INFO_METADATA)
    cargs = []
    cargs.append("SurfDsetInfo")
    cargs.append("[OPTIONS]")
    cargs.append("[DATASETS]")
    ret = SurfDsetInfoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_DSET_INFO_METADATA",
    "SurfDsetInfoOutputs",
    "surf_dset_info",
]
