# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EG_MAIN_CHRONO_PY_METADATA = Metadata(
    id="0b65e95e874d7a0a8d6d43a4d6a2803648fb76e7.boutiques",
    name="eg_main_chrono.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class EgMainChronoPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `eg_main_chrono_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def eg_main_chrono_py(
    help_: bool = False,
    history: bool = False,
    show_valid_options: bool = False,
    version: bool = False,
    verbosity_level: str | None = None,
    runner: Runner | None = None,
) -> EgMainChronoPyOutputs:
    """
    A sample main Python program to run on top of some library.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/eg_main_chrono.py.html
    
    Args:
        help_: Show help message.
        history: Show module history.
        show_valid_options: List valid options.
        version: Show current version.
        verbosity_level: Set the verbosity level.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EgMainChronoPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EG_MAIN_CHRONO_PY_METADATA)
    cargs = []
    cargs.append("eg_main_chrono.py")
    if help_:
        cargs.append("-help")
    if history:
        cargs.append("-hist")
    if show_valid_options:
        cargs.append("-show_valid_opts")
    if version:
        cargs.append("-ver")
    if verbosity_level is not None:
        cargs.extend([
            "-verb",
            verbosity_level
        ])
    ret = EgMainChronoPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EG_MAIN_CHRONO_PY_METADATA",
    "EgMainChronoPyOutputs",
    "eg_main_chrono_py",
]
