# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__GET_AFNI_ID_METADATA = Metadata(
    id="1911f86812e4cfffdcd0ca8b994f0db28b17e895.boutiques",
    name="@GetAfniID",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VGetAfniIdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__get_afni_id(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    unique_id: OutputPathType
    """Unique identifier of the dataset"""


def v__get_afni_id(
    dset: InputPathType,
    runner: Runner | None = None,
) -> VGetAfniIdOutputs:
    """
    Returns the unique identifier of a dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@GetAfniID.html
    
    Args:
        dset: Dataset for which the unique identifier is to be returned.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VGetAfniIdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__GET_AFNI_ID_METADATA)
    cargs = []
    cargs.append("GetAfniID")
    cargs.append(execution.input_file(dset))
    ret = VGetAfniIdOutputs(
        root=execution.output_file("."),
        unique_id=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VGetAfniIdOutputs",
    "V__GET_AFNI_ID_METADATA",
    "v__get_afni_id",
]
