# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

STD2IMGCOORD_METADATA = Metadata(
    id="688ec9ae6fa7e109f9dc1fbdb79eff77f4309cdf.boutiques",
    name="std2imgcoord",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Std2imgcoordOutputs(typing.NamedTuple):
    """
    Output object returned when calling `std2imgcoord(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def std2imgcoord(
    runner: Runner | None = None,
) -> Std2imgcoordOutputs:
    """
    Convert standard space coordinates to image space coordinates.
    
    Author: FMRIB Centre
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Std2imgcoordOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(STD2IMGCOORD_METADATA)
    cargs = []
    cargs.append("std2imgcoord")
    cargs.append("[OPTIONS]")
    cargs.append("<FILENAME_COORDINATES>")
    ret = Std2imgcoordOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "STD2IMGCOORD_METADATA",
    "Std2imgcoordOutputs",
    "std2imgcoord",
]
