# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_SUB_METADATA = Metadata(
    id="4a2ab1677f50e399301d58366587c073197f8285.boutiques",
    name="fsl_sub",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslSubOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_sub(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsl_sub(
    runner: Runner | None = None,
) -> FslSubOutputs:
    """
    FSL cluster submission tool.
    
    Author: FMRIB (Oxford University)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FslSub
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslSubOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_SUB_METADATA)
    cargs = []
    cargs.append("fsl_sub")
    cargs.append("[OPTIONS]")
    ret = FslSubOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_SUB_METADATA",
    "FslSubOutputs",
    "fsl_sub",
]
