# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WAVER_METADATA = Metadata(
    id="96b50e0c8292a4fbc3bac32ca89083846b0e7918.boutiques",
    name="waver",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class WaverOutputs(typing.NamedTuple):
    """
    Output object returned when calling `waver(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_filename: OutputPathType
    """The output filename for the result of the waveform."""


def waver(
    gam: bool = False,
    runner: Runner | None = None,
) -> WaverOutputs:
    """
    Creates an ideal waveform timeseries file.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/waver.html
    
    Args:
        gam: Sets waveform to form t^b * exp(-t/c) (cf. Mark Cohen).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WaverOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WAVER_METADATA)
    cargs = []
    cargs.append("waver")
    if gam:
        cargs.append("-GAM")
    cargs.append("[OPTIONS]")
    cargs.append(">")
    cargs.append("[OUTPUT_FILENAME]")
    ret = WaverOutputs(
        root=execution.output_file("."),
        output_filename=execution.output_file("output_filename"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WAVER_METADATA",
    "WaverOutputs",
    "waver",
]
