# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_WARP_METADATA = Metadata(
    id="274373e4ce98f7b2884dd886fb6749d0dbd8381d.boutiques",
    name="3dWarp",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dWarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_warp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_warp(
    dataset: str,
    runner: Runner | None = None,
) -> V3dWarpOutputs:
    """
    Warp (spatially transform) one 3D dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dWarp.html
    
    Args:
        dataset: Input dataset to be warped.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dWarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_WARP_METADATA)
    cargs = []
    cargs.append("3dWarp")
    cargs.append("[OPTIONS]")
    cargs.append(dataset)
    ret = V3dWarpOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dWarpOutputs",
    "V_3D_WARP_METADATA",
    "v_3d_warp",
]
