# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DEMO_PROMPT_METADATA = Metadata(
    id="d7d11524aa7bc99fbed5409167986014f1d0c85b.boutiques",
    name="@demo_prompt",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDemoPromptOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__demo_prompt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    status: OutputPathType
    """Status output: 0 if user presses OK, 1 if user cancels"""


def v__demo_prompt(
    message: str,
    runner: Runner | None = None,
) -> VDemoPromptOutputs:
    """
    Prompts user with a message and waits for acknowledgment.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@demo_prompt.html
    
    Args:
        message: The message to display in the prompt.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDemoPromptOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DEMO_PROMPT_METADATA)
    cargs = []
    cargs.append("@demo_prompt")
    cargs.append(message)
    ret = VDemoPromptOutputs(
        root=execution.output_file("."),
        status=execution.output_file("status"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDemoPromptOutputs",
    "V__DEMO_PROMPT_METADATA",
    "v__demo_prompt",
]
