# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

OXFORD_ASL_METADATA = Metadata(
    id="1225d433fbe151420738b535aab2a7687f83e294.boutiques",
    name="oxford_asl",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class OxfordAslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `oxford_asl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dir: OutputPathType
    """Directory containing the output files"""


def oxford_asl(
    asl_data: InputPathType,
    output_dir_name: str,
    runner: Runner | None = None,
) -> OxfordAslOutputs:
    """
    Calculate perfusion maps from ASL data.
    
    Author: FMRIB Centre, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/oxford_asl
    
    Args:
        asl_data: Input ASL data.
        output_dir_name: Output directory name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `OxfordAslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(OXFORD_ASL_METADATA)
    cargs = []
    cargs.append("oxford_asl")
    cargs.append("-i")
    cargs.append(execution.input_file(asl_data))
    cargs.append("-o")
    cargs.append(output_dir_name)
    cargs.append("[options]")
    ret = OxfordAslOutputs(
        root=execution.output_file("."),
        output_dir=execution.output_file(output_dir_name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "OXFORD_ASL_METADATA",
    "OxfordAslOutputs",
    "oxford_asl",
]
