# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DJUNCT_DWI_SELECTOR_TCSH_METADATA = Metadata(
    id="9b9b139284ac47200b7f4939472d4e18345a05e3.boutiques",
    name="@djunct_dwi_selector.tcsh",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDjunctDwiSelectorTcshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__djunct_dwi_selector_tcsh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """The main output file"""


def v__djunct_dwi_selector_tcsh(
    dwi: InputPathType,
    png: InputPathType,
    outfile: str,
    runner: Runner | None = None,
) -> VDjunctDwiSelectorTcshOutputs:
    """
    Selects DWI data and creates a representative image.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@djunct_dwi_selector.tcsh.html
    
    Args:
        dwi: Input DWI file.
        png: Output PNG image.
        outfile: Path to the output file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDjunctDwiSelectorTcshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DJUNCT_DWI_SELECTOR_TCSH_METADATA)
    cargs = []
    cargs.append("/opt/afni/src/../install/@djunct_dwi_selector.tcsh")
    cargs.append(execution.input_file(dwi))
    cargs.append(execution.input_file(png))
    cargs.append(outfile)
    ret = VDjunctDwiSelectorTcshOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDjunctDwiSelectorTcshOutputs",
    "V__DJUNCT_DWI_SELECTOR_TCSH_METADATA",
    "v__djunct_dwi_selector_tcsh",
]
