# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ROTCOM_METADATA = Metadata(
    id="82b02b85ea72d222e3f150bd7d5de9edb4b1ec75.boutiques",
    name="rotcom",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class RotcomOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rotcom(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stdout: OutputPathType
    """The 4x3 transformation matrix+vector output"""


def rotcom(
    rotate_ashift: str,
    dataset: InputPathType | None = None,
    runner: Runner | None = None,
) -> RotcomOutputs:
    """
    Prints to stdout the 4x3 transformation matrix+vector that would be applied by
    3drotate to the given dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/rotcom.html
    
    Args:
        rotate_ashift: Combination of rotate and ashift options in a single\
            quoted string (e.g., '-rotate 10I 0R 0A -ashift 5S 0 0').
        dataset: Input dataset for determining coordinate order.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RotcomOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ROTCOM_METADATA)
    cargs = []
    cargs.append("rotcom")
    cargs.append(rotate_ashift)
    if dataset is not None:
        cargs.append(execution.input_file(dataset))
    ret = RotcomOutputs(
        root=execution.output_file("."),
        stdout=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ROTCOM_METADATA",
    "RotcomOutputs",
    "rotcom",
]
