# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DCAT_METADATA = Metadata(
    id="5e596db6798d3b0d404e1685c84fe374efa6a71b.boutiques",
    name="1dcat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dcatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dcat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    concatenated_output: OutputPathType
    """Concatenated output in specified format"""


def v_1dcat(
    input_files: list[InputPathType],
    runner: Runner | None = None,
) -> V1dcatOutputs:
    """
    Concatenates columns of multiple 1D or TSV/CSV files.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dcat.html
    
    Args:
        input_files: Input 1D or TSV/CSV files to concatenate.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dcatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DCAT_METADATA)
    cargs = []
    cargs.append("1dcat")
    cargs.append("[OPTIONS]")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = V1dcatOutputs(
        root=execution.output_file("."),
        concatenated_output=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dcatOutputs",
    "V_1DCAT_METADATA",
    "v_1dcat",
]
