# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ESCAPE__METADATA = Metadata(
    id="f4258390d4b527039de0584cb728849422db04e3.boutiques",
    name="@escape-",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VEscapeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__escape_(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__escape_(
    help_: bool = False,
    runner: Runner | None = None,
) -> VEscapeOutputs:
    """
    A hypothetical command line tool for escaping sequences.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@escape-.html
    
    Args:
        help_: Display the help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VEscapeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ESCAPE__METADATA)
    cargs = []
    cargs.append("escape")
    if help_:
        cargs.append("-help")
    ret = VEscapeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VEscapeOutputs",
    "V__ESCAPE__METADATA",
    "v__escape_",
]
